@@ -1152,6 +1152,46 @@ module RubyIndexer
       assert_equal(2, foo_entry.location.start_line)
     end
 
+    def test_resolving_self_referential_constant_alias
+      index(<<~RUBY)
+        module A
+          module B
+            class C
+            end
+          end
+        end
+
+        module A
+          module D
+            B = B::C
+          end
+        end
+      RUBY
+
+      entry = @index.resolve("A::D::B", [])&.first #: as Entry::ConstantAlias
+
+      assert_kind_of(RubyIndexer::Entry::ConstantAlias, entry)
+      assert_equal(10, entry.location.start_line)
+      assert_equal("A::B::C", entry.target)
+    end
+
+    def test_resolving_non_existing_self_referential_constant_alias
+      index(<<~RUBY)
+        module Foo
+          SomeClass = ::SomeClass
+          UNRESOLVED = SomeClass::CONSTANT
+        end
+      RUBY
+
+      entry = @index.resolve("Foo::UNRESOLVED", [])&.first #: as Entry::UnresolvedConstantAlias
+      assert_kind_of(Entry::UnresolvedConstantAlias, entry)
+      assert_equal(3, entry.location.start_line)
+      assert_equal("SomeClass::CONSTANT", entry.target)
+
+      entry = @index.resolve("SomeClass::CONSTANT", ["Foo"])
+      refute(entry)
+    end
+
     def test_resolving_qualified_references
       index(<<~RUBY)
         module Namespace
@@ -1983,6 +2023,21 @@ module RubyIndexer
       assert_equal(["XQRK"], result.map { |entries| entries.first&.name })
     end
 
+    def test_constant_completion_does_not_confuse_uppercase_methods
+      index(<<~RUBY)
+        class Foo
+          def Qux
+          end
+        end
+      RUBY
+
+      candidates = @index.constant_completion_candidates("Q", [])
+      refute_includes(candidates.flat_map { |entries| entries.map(&:name) }, "Qux")
+
+      candidates = @index.constant_completion_candidates("Qux", [])
+      assert_equal(0, candidates.length)
+    end
+
     def test_constant_completion_candidates_for_empty_name
       index(<<~RUBY)
         module Foo
