@@ -2,11 +2,8 @@
 # frozen_string_literal: true
 
 module RubyLsp
+  #: [ParseResultType = Array[RBS::AST::Declarations::Base]]
   class RBSDocument < Document
-    extend T::Generic
-
-    ParseResultType = type_member { { fixed: T::Array[RBS::AST::Declarations::Base] } }
-
     #: (source: String, version: Integer, uri: URI::Generic, global_state: GlobalState) -> void
     def initialize(source:, version:, uri:, global_state:)
       @syntax_error = false #: bool
@@ -36,9 +33,9 @@ module RubyLsp
     end
 
     # @override
-    #: -> LanguageId
+    #: -> Symbol
     def language_id
-      LanguageId::RBS
+      :rbs
     end
   end
 end
